package WebService::Braintree::Dispute::Status;
$WebService::Braintree::Dispute::Status::VERSION = '0.94';
use 5.010_001;
use strictures 1;

use constant Open => 'open';
use constant Won => 'won';
use constant Lost => 'lost';

1;
__END__
